@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,10 +49,20 @@
 
 package com.openexchange.messaging.rss;
 
+import java.io.ByteArrayOutputStream;
+import java.io.IOException;
+import java.io.InputStream;
 import java.net.URL;
+import java.net.URLConnection;
 import java.util.ArrayList;
 import java.util.Collections;
 import java.util.List;
+import org.htmlcleaner.CleanerProperties;
+import org.htmlcleaner.HtmlCleaner;
+import org.htmlcleaner.Serializer;
+import org.htmlcleaner.SimpleXmlSerializer;
+import org.htmlcleaner.TagNode;
+import org.xml.sax.InputSource;
 import com.openexchange.messaging.IndexRange;
 import com.openexchange.messaging.MessagingAccountManager;
 import com.openexchange.messaging.MessagingContent;
@@ -68,7 +78,11 @@ import com.openexchange.messaging.generic.AttachmentFinderHandler;
 import com.openexchange.messaging.generic.MessageParser;
 import com.openexchange.messaging.generic.MessagingComparator;
 import com.openexchange.session.Session;
+import com.sun.syndication.feed.synd.SyndFeed;
 import com.sun.syndication.fetcher.FeedFetcher;
+import com.sun.syndication.fetcher.FetcherException;
+import com.sun.syndication.io.FeedException;
+import com.sun.syndication.io.SyndFeedInput;
 
 
 /**
@@ -80,14 +94,14 @@ public class RSSMessageAccess extends RSSCommon implements MessagingMessageAcces
 
     private final FeedFetcher feedFetcher;
     private final MessagingAccountManager accounts;
-    
+
     private FeedAdapter feed = null;
-    
-    public RSSMessageAccess(int accountId, Session session, FeedFetcher fetcher, MessagingAccountManager accounts) {
+
+    public RSSMessageAccess(final int accountId, final Session session, final FeedFetcher fetcher, final MessagingAccountManager accounts) {
         super(accountId, session);
         this.accountId = accountId;
         this.session = session;
-        this.feedFetcher = fetcher;
+        feedFetcher = fetcher;
         this.accounts = accounts;
     }
 
@@ -119,83 +133,83 @@ public class RSSMessageAccess extends RSSCommon implements MessagingMessageAcces
     }
 
 
-    public List<MessagingMessage> getAllMessages(String folder, IndexRange indexRange, MessagingField sortField, OrderDirection order, MessagingField... fields) throws MessagingException {
+    public List<MessagingMessage> getAllMessages(final String folder, final IndexRange indexRange, final MessagingField sortField, final OrderDirection order, final MessagingField... fields) throws MessagingException {
         return searchMessages(folder, indexRange, sortField, order, null, fields);
     }
 
-    public MessagingMessage getMessage(String folder, String id, boolean peek) throws MessagingException {
+    public MessagingMessage getMessage(final String folder, final String id, final boolean peek) throws MessagingException {
         checkFolder(folder);
         return loadFeed().get(id);
     }
 
-    public List<MessagingMessage> getMessages(String folder, String[] messageIds, MessagingField[] fields) throws MessagingException {
+    public List<MessagingMessage> getMessages(final String folder, final String[] messageIds, final MessagingField[] fields) throws MessagingException {
         checkFolder(folder);
-        List<MessagingMessage> messages = new ArrayList<MessagingMessage>(messageIds.length);
-        for (String id : messageIds) {
+        final List<MessagingMessage> messages = new ArrayList<MessagingMessage>(messageIds.length);
+        for (final String id : messageIds) {
             messages.add(getMessage(folder, id, true));
         }
         return messages;
     }
 
-    public List<String> moveMessages(String sourceFolder, String destFolder, String[] messageIds, boolean fast) throws MessagingException {
+    public List<String> moveMessages(final String sourceFolder, final String destFolder, final String[] messageIds, final boolean fast) throws MessagingException {
         checkFolder(sourceFolder);
         checkFolder(destFolder);
         throw MessagingExceptionCodes.OPERATION_NOT_SUPPORTED.create(RSSMessagingService.ID);
     }
 
-    public MessagingMessage perform(String folder, String id, String action) throws MessagingException {
+    public MessagingMessage perform(final String folder, final String id, final String action) throws MessagingException {
         throw MessagingExceptionCodes.UNKNOWN_ACTION.create(action);
     }
 
-    public MessagingMessage perform(String action) throws MessagingException {
+    public MessagingMessage perform(final String action) throws MessagingException {
         throw MessagingExceptionCodes.UNKNOWN_ACTION.create(action);
     }
 
-    public MessagingMessage perform(MessagingMessage message, String action) throws MessagingException {
+    public MessagingMessage perform(final MessagingMessage message, final String action) throws MessagingException {
         throw MessagingExceptionCodes.UNKNOWN_ACTION.create(action);
     }
 
-    public List<MessagingMessage> searchMessages(String folder, IndexRange indexRange, MessagingField sortField, OrderDirection order, SearchTerm<?> searchTerm, MessagingField[] fields) throws MessagingException {
+    public List<MessagingMessage> searchMessages(final String folder, final IndexRange indexRange, final MessagingField sortField, final OrderDirection order, final SearchTerm<?> searchTerm, final MessagingField[] fields) throws MessagingException {
         checkFolder(folder);
         List<SyndMessage> messages = loadFeed().getMessages();
-        
+
         messages = filter(messages, searchTerm);
         sort(messages, sortField, order);
         messages = sublist(messages, indexRange);
-        
+
         return new ArrayList<MessagingMessage>(messages);
     }
 
-    private List<SyndMessage> sublist(List<SyndMessage> messages, IndexRange indexRange) {
+    private List<SyndMessage> sublist(final List<SyndMessage> messages, final IndexRange indexRange) {
         if(indexRange == null) {
             return messages;
         }
         int start = Math.min(indexRange.getStart(), messages.size()-1);
         int end = Math.min(indexRange.getEnd(), messages.size()-1);
-        
+
         if (start < 0) {
             start = 0;
         }
-        
+
         if(end < 0) {
             end = 0;
         }
-        
+
         return messages.subList(start, end);
     }
 
-    private void sort(List<SyndMessage> messages, MessagingField sortField, OrderDirection order) throws MessagingException {
+    private void sort(final List<SyndMessage> messages, final MessagingField sortField, final OrderDirection order) throws MessagingException {
         if(sortField == null) {
             return;
         }
-        MessagingComparator comparator = new MessagingComparator(sortField, null);
+        final MessagingComparator comparator = new MessagingComparator(sortField, null);
         try {
             Collections.sort(messages, comparator);
             if(order == OrderDirection.DESC) {
                 Collections.reverse(messages);
             }
-        } catch (RuntimeException x) {
-            Throwable cause = x.getCause();
+        } catch (final RuntimeException x) {
+            final Throwable cause = x.getCause();
             if(MessagingException.class.isInstance(cause)) {
                 throw (MessagingException) cause;
             }
@@ -203,14 +217,14 @@ public class RSSMessageAccess extends RSSCommon implements MessagingMessageAcces
         }
     }
 
-    private List<SyndMessage> filter(List<SyndMessage> messages, SearchTerm<?> searchTerm) throws MessagingException {
+    private List<SyndMessage> filter(final List<SyndMessage> messages, final SearchTerm<?> searchTerm) throws MessagingException {
         if(searchTerm == null) {
             return messages;
         }
-        
-        List<SyndMessage> list = new ArrayList<SyndMessage>(messages.size());
-        
-        for (SyndMessage syndMessage : list) {
+
+        final List<SyndMessage> list = new ArrayList<SyndMessage>(messages.size());
+
+        for (final SyndMessage syndMessage : list) {
             if(searchTerm.matches(syndMessage)) {
                 list.add(syndMessage);
             }
@@ -218,24 +232,100 @@ public class RSSMessageAccess extends RSSCommon implements MessagingMessageAcces
         return list;
     }
 
-    public void updateMessage(MessagingMessage message, MessagingField[] fields) throws MessagingException {
+    public void updateMessage(final MessagingMessage message, final MessagingField[] fields) throws MessagingException {
         throw MessagingExceptionCodes.OPERATION_NOT_SUPPORTED.create(RSSMessagingService.ID);
     }
-    
+
     private FeedAdapter loadFeed() throws MessagingException {
         if(feed != null) {
             return feed;
         }
-        String url = (String) accounts.getAccount(accountId, session).getConfiguration().get("url");
-        
+        final String url = (String) accounts.getAccount(accountId, session).getConfiguration().get("url");
+
         try {
-            return this.feed = new FeedAdapter(feedFetcher.retrieveFeed(new URL(url)), "");
-        } catch (Exception e) {
+            return feed = new FeedAdapter(retrieveFeed(new URL(url)), "", session);
+        } catch (final Exception e) {
             throw MessagingExceptionCodes.MESSAGING_ERROR.create(e, e.getMessage());
         }
     }
 
-    public MessagingContent resolveContent(String folder, String id, String referenceId) throws MessagingException {
+    /**
+     * The {@link HtmlCleaner} constant which is safe being used by multiple threads as of <a
+     * href="http://htmlcleaner.sourceforge.net/javause.php#example2">this example</a>.
+     */
+    private static final HtmlCleaner HTML_CLEANER;
+
+    /**
+     * The {@link Serializer} constant which is safe being used by multiple threads as of <a
+     * href="http://htmlcleaner.sourceforge.net/javause.php#example2">this example</a>.
+     */
+    private static final Serializer SERIALIZER;
+
+    static {
+        final CleanerProperties props = new CleanerProperties();
+        /*-
+         * 
+        props.setOmitDoctypeDeclaration(true);
+        props.setOmitXmlDeclaration(true);
+        props.setTransSpecialEntitiesToNCR(true);
+        props.setTransResCharsToNCR(true);
+        props.setRecognizeUnicodeChars(false);
+        props.setUseEmptyElementTags(false);
+        props.setIgnoreQuestAndExclam(false);
+        props.setUseCdataForScriptAndStyle(false);
+        props.setIgnoreQuestAndExclam(true);
+         * 
+         */
+        HTML_CLEANER = new HtmlCleaner(props);
+        SERIALIZER = new SimpleXmlSerializer(props);
+    }
+
+    private SyndFeed retrieveFeed(final URL url) throws IOException, FeedException, FetcherException {
+        try {
+            return feedFetcher.retrieveFeed(url);
+        } catch (final com.sun.syndication.io.ParsingFeedException e) {
+            // Retry using InputSource class
+            InputStream in = null;
+            try {
+                final SyndFeedInput input = new SyndFeedInput();
+                final URLConnection urlConnection = url.openConnection();
+                urlConnection.connect();
+                in = urlConnection.getInputStream();
+                /*
+                 * Read from stream
+                 */
+                final int initLen = 8192;
+                ByteArrayOutputStream tmp = new ByteArrayOutputStream(initLen);
+                final int blen = 2048;
+                final byte[] buf = new byte[blen];
+                for (int read; (read = in.read(buf, 0, blen)) > 0;) {
+                    tmp.write(buf, 0, read);
+                }
+                /*
+                 * Ensure well-formed
+                 */
+                final TagNode htmlNode = HTML_CLEANER.clean(new String(tmp.toByteArray())); // No charset needed???
+                tmp = null;
+                final UnsynchronizedStringWriter writer = new UnsynchronizedStringWriter(initLen);
+                SERIALIZER.write(htmlNode, writer, "UTF-8");
+                final StringBuilder builder = writer.getBuffer();
+                /*
+                 * Return feed
+                 */
+                return input.build(new InputSource(new UnsynchronizedStringReader(builder.toString())));
+            } finally {
+                if (null != in) {
+                    try {
+                        in.close();
+                    } catch (final Exception ignore) {
+                        // Ignore
+                    }
+                }
+            }
+        }
+    }
+
+    public MessagingContent resolveContent(final String folder, final String id, final String referenceId) throws MessagingException {
         throw new UnsupportedOperationException();
     }
 
